==> zio-aws-fsx_2.12-5.17.124.3-sources.jar: zio/aws/fsx/model/OpenZFSDataCompressionType.scala <==
package zio.aws.fsx.model
import scala.jdk.CollectionConverters._
sealed trait OpenZFSDataCompressionType {
  def unwrap
      : software.amazon.awssdk.services.fsx.model.OpenZFSDataCompressionType
}
object OpenZFSDataCompressionType {
  def wrap(
      value: software.amazon.awssdk.services.fsx.model.OpenZFSDataCompressionType
  ): zio.aws.fsx.model.OpenZFSDataCompressionType = value match {
    case software.amazon.awssdk.services.fsx.model.OpenZFSDataCompressionType.UNKNOWN_TO_SDK_VERSION =>
      val r = unknownToSdkVersion
      r
    case software.amazon.awssdk.services.fsx.model.OpenZFSDataCompressionType.NONE =>
      val r = NONE
      r
    case software.amazon.awssdk.services.fsx.model.OpenZFSDataCompressionType.ZSTD =>
      val r = ZSTD
      r
  }
  case object unknownToSdkVersion
      extends zio.aws.fsx.model.OpenZFSDataCompressionType {
    override def unwrap
        : software.amazon.awssdk.services.fsx.model.OpenZFSDataCompressionType =
      software.amazon.awssdk.services.fsx.model.OpenZFSDataCompressionType.UNKNOWN_TO_SDK_VERSION
  }
  case object NONE extends zio.aws.fsx.model.OpenZFSDataCompressionType {
    override def unwrap
        : software.amazon.awssdk.services.fsx.model.OpenZFSDataCompressionType =
      software.amazon.awssdk.services.fsx.model.OpenZFSDataCompressionType.NONE
  }
  case object ZSTD extends zio.aws.fsx.model.OpenZFSDataCompressionType {
    override def unwrap
        : software.amazon.awssdk.services.fsx.model.OpenZFSDataCompressionType =
      software.amazon.awssdk.services.fsx.model.OpenZFSDataCompressionType.ZSTD
  }
}

==> zio-aws-fsx_2.13-5.17.164.1-sources.jar: zio/aws/fsx/model/OpenZFSDataCompressionType.scala <==
package zio.aws.fsx.model
import scala.jdk.CollectionConverters._
sealed trait OpenZFSDataCompressionType {
  def unwrap
      : software.amazon.awssdk.services.fsx.model.OpenZFSDataCompressionType
}
object OpenZFSDataCompressionType {
  def wrap(
      value: software.amazon.awssdk.services.fsx.model.OpenZFSDataCompressionType
  ): zio.aws.fsx.model.OpenZFSDataCompressionType = value match {
    case software.amazon.awssdk.services.fsx.model.OpenZFSDataCompressionType.UNKNOWN_TO_SDK_VERSION =>
      val r = unknownToSdkVersion
      r
    case software.amazon.awssdk.services.fsx.model.OpenZFSDataCompressionType.NONE =>
      val r = NONE
      r
    case software.amazon.awssdk.services.fsx.model.OpenZFSDataCompressionType.ZSTD =>
      val r = ZSTD
      r
    case software.amazon.awssdk.services.fsx.model.OpenZFSDataCompressionType.LZ4 =>
      val r = LZ4
      r
  }
  case object unknownToSdkVersion
      extends zio.aws.fsx.model.OpenZFSDataCompressionType {
    override def unwrap
        : software.amazon.awssdk.services.fsx.model.OpenZFSDataCompressionType =
      software.amazon.awssdk.services.fsx.model.OpenZFSDataCompressionType.UNKNOWN_TO_SDK_VERSION
  }
  case object NONE extends zio.aws.fsx.model.OpenZFSDataCompressionType {
    override def unwrap
        : software.amazon.awssdk.services.fsx.model.OpenZFSDataCompressionType =
      software.amazon.awssdk.services.fsx.model.OpenZFSDataCompressionType.NONE
  }
  case object ZSTD extends zio.aws.fsx.model.OpenZFSDataCompressionType {
    override def unwrap
        : software.amazon.awssdk.services.fsx.model.OpenZFSDataCompressionType =
      software.amazon.awssdk.services.fsx.model.OpenZFSDataCompressionType.ZSTD
  }
  case object LZ4 extends zio.aws.fsx.model.OpenZFSDataCompressionType {
    override def unwrap
        : software.amazon.awssdk.services.fsx.model.OpenZFSDataCompressionType =
      software.amazon.awssdk.services.fsx.model.OpenZFSDataCompressionType.LZ4
  }
}
